package Agent::TCLI::Package::Net;
#
# $Id: Net.pm 74 2007-06-08 00:42:53Z hacker $
#
=pod

=head1 NAME

Agent::TCLI::Package::Net - Network related commands for TCLI Agents

=head1 SYNOPSIS

This is documentation and version only module.

=head1 DESCRIPTION

This is a collection of network related TCLI packages. At some point, some of
the parameters and methods that are common between the network packages may move
into this module as a base class, but right now it is just a POD document and
placeholder.

=cut

our $VERSION = '0.031';

1;
#__END__

=head1 AUTHOR

Eric Hacker	 E<lt>hacker at cpan.orgE<gt>

=head1 BUGS

This is only documentation, but there is probably a speeling error or a
grammer mistake lurking about.

=head1 LICENSE

Copyright (c) 2007, Alcatel Lucent, All rights resevred.

This package is free software; you may redistribute it
and/or modify it under the same terms as Perl itself.

=cut
